Struct AaSupport

pub struct AaSupport {
    pub area: bool,
    pub msaa8: bool,
    pub msaa16: bool,
}
Represents the set of anti-aliasing configurations to enable during pipeline creation.

This is configured at Renderer creation time (Renderer::new) by setting RendererOptions::antialiasing_support.

This can be created from a set of AaConfig using Iterator::collect, as AaSupport implements FromIterator.

Fields

area: bool

Support AaConfig::Area.

msaa8: bool

Support AaConfig::Msaa8.

msaa16: bool

Implementations

Source

impl AaSupport

pub fn all() -> Self

Support every anti-aliasing method.

This might increase startup time, as more shader variations must be compiled.

pub fn area_only() -> Self

Support only AaConfig::Area.

This should be the default choice for most users.