pub struct RenderParams {
pub base_color: Color,
pub width: u32,
pub height: u32,
pub antialiasing_method: AaConfig,
}Expand description
Parameters used in a single render that are configurable by the client.
These are used in Renderer::render_to_texture.
Fields
base_color: ColorThe background color applied to the target. This value is only applicable to the full pipeline.
width: u32Dimensions of the rasterization target
height: u32antialiasing_method: AaConfigThe anti-aliasing algorithm. The selected algorithm must have been initialized while
constructing the Renderer.